# TinyTim

A pure python package used to process a table of data stored in a dict.

## Description

Use TinyTim instead of Pandas to process your data if you do not want to install Pandas and its many dependencies.
TinyTim has no dependencies outside Python.

## Getting Started

### Dependencies

* Python>=3.6

### Installing

* pip install tinytim

### Executing program

* How to run the program
* Step-by-step bullets
```
Example code to come.
```

## Authors

Contributors names and contact info

Odos Matthews: odosmatthews@gmail.com

## License

This project is licensed under the MIT License - see the LICENSE.md file for details